@@ -23,8 +23,7 @@ Boston, MA 02111-1307, USA.
 #include <config.h>
 #include <string.h>
 #include <locale.h>
-#include <gdk/gdkx.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gtkhtml.h"
 #include "gtkhtml-properties.h"
 #include "htmlfontmanager.h"
@@ -36,12 +35,16 @@ Boston, MA 02111-1307, USA.
 
 /* this function is reworked gal:e-iconv.c:e_iconv_locale_language */
 static gchar *
-get_locale_language ()
+get_locale_language (void)
 {
 	gchar *locale;
 	gchar *locale_language = NULL;
 	
+#ifndef G_OS_WIN32
 	locale = setlocale (LC_ALL, NULL);
+#else
+	locale = g_win32_getlocale ();
+#endif
 	if (locale && strcmp (locale, "C") && strcmp (locale, "POSIX")) {
 		char *codeset, *lang;
 	
@@ -142,7 +145,7 @@ static GEnumValue _gtk_html_cursor_skip_values[] = {
 };
 
 GType
-gtk_html_cursor_skip_get_type ()
+gtk_html_cursor_skip_get_type (void)
 {
 	static GType cursor_skip_type = 0;
 
@@ -303,11 +306,16 @@ static GEnumValue _gtk_html_command_values[] = {
 	{ GTK_HTML_COMMAND_CELL_RSPAN_DEC, "GTK_HTML_COMMAND_CELL_RSPAN_DEC", "rspan-dec" },
 	{ GTK_HTML_COMMAND_EDITABLE_ON, "GTK_HTML_COMMAND_EDITABLE_ON", "editable-on" },
 	{ GTK_HTML_COMMAND_EDITABLE_OFF, "GTK_HTML_COMMAND_EDITABLE_OFF", "editable-off" },
+	{ GTK_HTML_COMMAND_BLOCK_SELECTION, "GTK_HTML_COMMAND_BLOCK_SELECTION", "block-selection" },
+	{ GTK_HTML_COMMAND_UNBLOCK_SELECTION, "GTK_HTML_COMMAND_UNBLOCK_SELECTION", "unblock-selection" },
+	{ GTK_HTML_COMMAND_IS_SELECTION_ACTIVE, "GTK_HTML_COMMAND_IS_SELECTION_ACTIVE", "is-selection-active" },
+	{ GTK_HTML_COMMAND_SCROLL_FORWARD, "GTK_HTML_COMMAND_SCROLL_FORWARD", "scroll-forward" },
+	{ GTK_HTML_COMMAND_SCROLL_BACKWARD, "GTK_HTML_COMMAND_SCROLL_BACKWARD", "scroll-backward" },	
 	{ 0, NULL, NULL }
 };
 
 GType
-gtk_html_command_get_type ()
+gtk_html_command_get_type (void)
 {
 	static GType command_type = 0;
 
