@@ -123,10 +123,8 @@ static GList *
 point_get_parent_list (HTMLPoint *point, gint level, gboolean include_offset)
 {
 	GList *list;
-	HTMLObject *o;
 
 	list = include_offset ? g_list_prepend (NULL, GINT_TO_POINTER (point->offset)) : NULL;
-	o    = point->object;
 
 	object_get_parent_list (point->object, level, &list);
 
@@ -224,10 +222,19 @@ prepare_delete_bounds (HTMLEngine *e, GList **from_list, GList **to_list,
 }
 
 static void
-remove_empty_and_merge (HTMLEngine *e, gboolean merge, GList *left, GList *right, HTMLCursor *c)
+remove_empty_and_merge (HTMLEngine *e, gboolean merge, GList *left_orig, GList *right_orig, HTMLCursor *c)
 {
 	HTMLObject *lo, *ro, *prev;
 
+	GList *left, *right;
+	GList *left_old, *right_old;
+
+	left_old = g_list_copy (left_orig);
+	right_old = g_list_copy (right_orig);
+
+	left = left_old;
+	right = right_old;
+
 #ifdef OP_DEBUG
 	/* HTMLObject *left_orig = left->data; */
 	printf ("before merge\n");
@@ -310,7 +317,22 @@ remove_empty_and_merge (HTMLEngine *e, gboolean merge, GList *left, GList *right
 		}
 
 		if (merge && lo && ro) {
-			if (!html_object_merge (lo, ro, e, &left, &right, c))
+			GList *left_copy, *right_copy;
+			gboolean merge_flag;
+
+			left_copy = g_list_copy (left);
+			right_copy = g_list_copy (right);
+			merge_flag = html_object_merge (lo, ro, e, &left_copy, &right_copy, c);
+
+			g_list_free (left_old);
+			g_list_free (right_old);
+
+			left = left_copy;
+			right = right_copy;
+			left_old = left;
+			right_old = right;
+
+			if (!merge_flag)
 				break;
 			if (ro == e->cursor->object) {
 				e->cursor->object  = lo;
@@ -324,6 +346,9 @@ remove_empty_and_merge (HTMLEngine *e, gboolean merge, GList *left, GList *right
 		e->cursor->object = prev;
 		e->cursor->offset = html_object_get_length (e->cursor->object);
 	}
+
+	g_list_free (left_old);
+	g_list_free (right_old);
 #ifdef OP_DEBUG
 	/* printf ("-- finished\n");
 	   gtk_html_debug_dump_tree_simple (left_orig, 0); */
@@ -786,6 +811,19 @@ html_engine_cut (HTMLEngine *e)
 
 	html_engine_clipboard_clear (e);
 	html_undo_level_begin (e->undo, "Cut", "Uncut");
+	if (html_engine_is_selection_active (e)) {
+		HTMLCursor *start = html_cursor_dup (e->mark->position < e->cursor->position ? e->mark : e->cursor);
+		HTMLCursor *end = html_cursor_dup (e->mark->position < e->cursor->position ? e->cursor : e->mark);
+		gint start_position = start->position;
+		gint end_position = end->position;
+		if (end_position - start_position > 0) {
+			int len = end_position - start_position;
+			g_signal_emit_by_name (e->widget, "object_delete", start_position, len);
+		}
+		html_cursor_destroy (start);
+		html_cursor_destroy (end);
+	}
+
 	rv = delete_object (e, &e->clipboard, &e->clipboard_len, HTML_UNDO_UNDO, TRUE);
 	html_undo_level_end (e->undo);
 
@@ -1498,9 +1536,6 @@ change_link (HTMLObject *o, HTMLEngine *e, gpointer data)
 	changed = d->url ? html_object_set_link (o, d->color, d->url, d->target) : html_object_remove_link (o, d->color);
 	if (changed) {
 		if (o->parent) {
-			HTMLObject *prev;
-
-			prev = o->prev;
 			g_assert (HTML_OBJECT_TYPE (o->parent) == HTML_TYPE_CLUEFLOW);
 
 			html_clue_append_after (HTML_CLUE (o->parent), changed, o);
